@@ -12,9 +12,9 @@ class PrinterTableGateway(metaclass=ABCMeta):
         "print_table_findings"
 
     @abstractmethod
-    def print_table_report(self, report_list: "list[Report]"):
+    def print_table_report(self, report_list: "list[Report]", finding_score_model):
         "print_table_report"
 
     @abstractmethod
-    def print_table_exclusions(self, exclusions_list):
+    def print_table_exclusions(self, exclusions_list, break_build_manager):
         "print_table_exclusions"
\ No newline at end of file
