@@ -36,4 +36,6 @@ class Report:
         self.file_path = kwargs.get("file_path", "")
         self.endpoints = kwargs.get("endpoints", "")
         self.unique_id_from_tool = kwargs.get("unique_id_from_tool", "")
-        self.out_of_scope = kwargs.get("out_of_scope", "")
\ No newline at end of file
+        self.out_of_scope = kwargs.get("out_of_scope", "")
+        self.priority = kwargs.get("priority", "")
+        self.priority_classification = kwargs.get("priority_classification", "")
\ No newline at end of file
