@@ -13,6 +13,12 @@ from devsecops_engine_tools.engine_sast.engine_secret.src.infrastructure.driven_
 from devsecops_engine_tools.engine_sast.engine_secret.src.infrastructure.driven_adapters.gitleaks.gitleaks_deserealizator import (
     GitleaksDeserealizator
     )
+from devsecops_engine_tools.engine_sast.engine_secret.src.infrastructure.driven_adapters.all_tools.all_tools import (
+    AllToolsSecretScan
+)
+from devsecops_engine_tools.engine_sast.engine_secret.src.infrastructure.driven_adapters.all_tools.all_tools_deserealizator import (
+    AllToolsSecretScanDeserealizator
+)   
 from devsecops_engine_tools.engine_utilities.git_cli.infrastructure.git_run import (
     GitRun
     )
@@ -28,6 +34,9 @@ def runner_secret_scan(dict_args, tool, devops_platform_gateway, remote_config_s
         elif (tool == "GITLEAKS"):
             tool_gateway = GitleaksTool()
             tool_deserealizator = GitleaksDeserealizator()
+        elif (tool == "ALL_TOOLS"):
+            tool_gateway = AllToolsSecretScan()
+            tool_deserealizator = AllToolsSecretScanDeserealizator()
 
         return engine_secret_scan(
             devops_platform_gateway = devops_platform_gateway,
